@@ -29,13 +29,16 @@ our @EXPORT = qw(
 our @ISA = qw(Exporter);
 
 # Set the package version. 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 # Load the Perl modules.
 use POSIX qw(ttyname);
 
+# Define directory for Inline. 
+use Inline Config => DIRECTORY => '/tmp/';
+
 # Use inline C code.
-#use Inline 'C';
+use Inline 'C';
 
 # Define the Perl BEGIN block.
 BEGIN {
@@ -123,6 +126,26 @@ sub trim {
     return $str;    
 };
 
+#------------------------------------------------------------------------------# 
+# Subroutine search_brackets                                                   #
+#                                                                              #
+# Description:                                                                 #
+# The subroutine adds the square brackets [ and ] to the searchstring for      #
+# use with grep. E.g. shell becomes [s]hell.                                   # 
+#                                                                              #
+# @argument: $_[0]  Searchstring                       (scalar)                #
+# @return:   $str   Searchstring with square brackets  (scalar)                #
+#------------------------------------------------------------------------------# 
+sub search_brackets {
+    # Assign the subroutine argument to the local variable.  
+    my $str = $_[0];
+    # Add square brackets [ and ] to the given string.
+    substr($str, 0, 0) = '[';
+    substr($str, 2, 0) = ']';
+    # Return the modified string.
+    return $str;
+};
+
 #------------------------------------------------------------------------------# 
 # Subroutine read_file                                                         #
 #                                                                              #
@@ -300,14 +323,17 @@ sub term_user_shell {
 sub terminal_process {
     # Assign the subroutine argument to the local variable.
     my @data = @{$_[0]};
-    # Declare the return array.
-    my @match;
+    # Initialise the return array.
+    my @match = ();
     # Loop over the elements of the array.
     foreach my $item (@data) {
         # Get term, user and shell from the array.
         my $term = $item->[0];
         my $user = $item->[1];
         my $shell = $item->[2];
+        $term = search_brackets($term);
+        $user = search_brackets($user);
+        $shell = search_brackets($shell);
         # Search for processes which is matching shell, user and terminal.
         my $process = `ps aux | grep $shell | grep $user | grep $term`;
         # Check if the result is not empty.
@@ -323,6 +349,9 @@ sub terminal_process {
             # Get term and user from the array.
             my $term = $item->[0];
             my $user = $item->[1];
+            # Add square brackets to searchstrings.
+            $term = search_brackets($term);
+            $user = search_brackets($user);
             # Search for processes which is matching shell and terminal.
             my $process = `ps aux | grep $user | grep $term | grep "?" | grep "sshd"`;
             # Check if the result is not empty.
@@ -556,15 +585,18 @@ package variable
 
   $OutputFormat
 
-which can be used to control the format of the output of the identified terminal.
-If the global package variable is set, the method arguments are ignored if existing
-in the method call.
+which can be used to control the format of the output of the identified
+terminal. If the global package variable is set, the method arguments are
+ignored if existing in the method call.
 
 =head1 DESCRIPTION
 
 The main objective of this package is to provide a method which is capable of
 identifying the terminal emulator a logged-in user is actual using. 
 
+According to the current state of development, it can also be recognised whether
+it is the System Console or a remotely used System Console. 
+
 The logged-in user is related to a valid login shell. Knowing this, the
 logged-in user as well as the login shell of the logged-in user are determined.
 Next the terminal path to the pseudo terminal slave (pts) is identified. Based
@@ -572,9 +604,13 @@ on this informations the related process of the logged-in user, the login shell
 and the terminal path is determined. The evaluation of the PID of the process of
 the running Perl script results in the PPID. The command related to this PPID
 is the name of the terminal emulator in use. Not only a terminal emulator can be
-identified by this package, it is also able to detect if a system console is being
-used by a logged-in user. The package also works if different terminal emulators
-are used and when they were spawned from on initial started terminal emulator.
+identified by this package, it is also able to detect if a system console is
+being used by a logged-in user. The package also works if different terminal
+emulators are used and when they were spawned from on initial started terminal
+emulator.
+
+Changing a user and using su and sudo are currently no longer a problem for
+the detection of a terminal emulator.
 
 The terminal emulator in use by the logged-in user can be identified by the
 main command C<whichterminalami()> and the other defined aliases.
@@ -763,8 +799,9 @@ Terminal emulators tested so far with the package:
 
 The limitations of the package are given by the Linux commands and the Linux
 system files which are used by the package. The Linux command C<ps>, the Linux
-command C<users> and the Linux command C<which> must be available. The Linux
-system files C</etc/shells> and C</etc/passwd> must be exist.
+command C<users>, the Linux command C<which> and the Linux command C<grep> must
+be available. The Linux system files C</etc/shells> and C</etc/passwd> must be
+exist.
 
 =head1 OPEN ISSUES
 
@@ -774,7 +811,7 @@ and the necessary system files are available.
 =head1 KNOWN BUGS
 
 The terminal emulator WezTerm can not be identified. Reason is a missing pseudo
-terminal slave while analysing coupled terminal window.
+terminal slave while analysing the coupled terminal window.
 
 =head1 ERROR CODES
 
@@ -786,6 +823,19 @@ Problems were found with the use of the Inline C module. The problem is caused
 by user and root rights. Until this issue is resolved, the POSIX module is used
 instead of the C code.
 
+=head1 PROGRAM-TECHNICAL BACKGROUND
+
+The Linux command ps can be used e.g. in BASH to find out, which terminal emulator 
+is in use by the current user. The command line to do this is quite easy: 
+
+  ps -o 'cmd=' -p $(ps -o 'ppid=' -p $$)
+
+If this is done from within a script it fails. There are a few hurdles to overcome
+in order to carry out this procedure from a script.
+
+A distinction must be made between user and superuser. Using su or sudo makes a
+difference for running a script.
+
 =head1 ABSTRACT
 
 The module identifies the terminal emulator which the logged-in user is using
